@@ -1,6 +1,6 @@
-use once_cell::sync::Lazy;
-use scoped_tls::scoped_thread_local;
 use std::sync::atomic::{AtomicBool, Ordering};
+
+use once_cell::sync::Lazy;
 use swc_common::{FileName, FilePathMapping, Mark, SourceMap, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_parser::{lexer::Lexer, Parser, StringInput};
@@ -60,7 +60,7 @@ macro_rules! add_to {
     }};
 }
 
-scoped_thread_local!(
+better_scoped_tls::scoped_tls!(
     /// This variable is used to manage helper scripts like `_inherits` from babel.
     ///
     /// The instance contains flags where each flag denotes if a helper script should be injected.
@@ -87,6 +87,7 @@ impl Helpers {
     pub const fn mark(&self) -> Mark {
         self.mark.0
     }
+
     pub const fn external(&self) -> bool {
         self.external
     }
@@ -336,11 +337,12 @@ impl VisitMut for Marker {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
-    use crate::pass::noop;
     use swc_ecma_visit::{as_folder, FoldWith};
     use testing::DebugUsingDisplay;
 
+    use super::*;
+    use crate::pass::noop;
+
     #[test]
     fn external_helper() {
         let input = "_throw()
